@@ -8,6 +8,7 @@ from . import log as stash_logger
 from .types import PhashDistance
 from .classes import GQLWrapper
 from .classes import SQLiteWrapper
+from .classes import StashVersion
 
 class StashInterface(GQLWrapper):
 	port = ""
@@ -21,12 +22,13 @@ class StashInterface(GQLWrapper):
 	}
 	cookies = {}
 
-	def __init__(self, conn:dict={}, fragments:list[str]=[stashapp_gql_fragments.DEVELOP]):
-		global log
-
+	def __init__(self, conn:dict={}, fragments:list[str]=[]):
 		conn = CaseInsensitiveDict(conn)
 
-		log = conn.get("Logger", stash_logger)
+		self.log = conn.get("Logger", stash_logger)
+
+		if conn.get("ApiKey"):
+			self.headers["ApiKey"] = conn["ApiKey"]
 
 		# Session cookie for authentication
 		self.cookies = {}
@@ -45,11 +47,15 @@ class StashInterface(GQLWrapper):
 			# test query to ensure good connection
 			version = self.stash_version()
 		except Exception as e:
-			log.error(f"Could not connect to Stash at {self.url}")
-			log.error(e)
+			self.log.error(f"Could not connect to Stash at {self.url}")
+			self.log.error(e)
 			sys.exit()
 			
-		log.debug(f'Using stash ({version["version"]}) endpoint at {self.url}')
+		self.log.debug(f'Using stash ({version}) endpoint at {self.url}')
+
+		if fragments == []:
+			self.log.debug("Using DEVELOP fragments")
+			fragments.append(stashapp_gql_fragments.DEVELOP)
 
 		self.fragments = {}
 		for fragment in fragments:
@@ -77,24 +83,30 @@ class StashInterface(GQLWrapper):
 		item_matches = {}
 		for item in items:
 			if re.match(rf'{search}$', item["name"], re.IGNORECASE):
-				log.debug(f'matched "{search}" to "{item["name"]}" ({item["id"]}) using primary name')
+				self.log.debug(f'matched "{search}" to "{item["name"]}" ({item["id"]}) using primary name')
 				item_matches[item["id"]] = item
 				return list(item_matches.values())
+		for item in items:
 			if not item["aliases"]:
 				continue
 			for alias in item["aliases"]:
 				if re.match(rf'{search}$', alias.strip(), re.IGNORECASE):
-					log.info(f'matched "{search}" to "{item["name"]}" ({item["id"]}) using alias')
+					self.log.info(f'matched "{search}" to "{item["name"]}" ({item["id"]}) using alias')
 					item_matches[item["id"]] = item
 		return list(item_matches.values())
 
 	def __match_performer_alias(self, search, performers):
 		item_matches = {}
+
+		# attempt to match exclusivly to primary name
 		for item in performers:
 			if re.match(rf'{search}$', item["name"], re.IGNORECASE):
-				log.info(f'matched "{search}" to "{item["name"]}" ({item["id"]}) using primary name')
+				self.log.info(f'matched performer "{search}" to "{item["name"]}" ({item["id"]}) using primary name')
 				item_matches[item["id"]] = item
 				return list(item_matches.values())
+
+		# no match on primary name attempt aliases
+		for item in performers:
 			if not item["aliases"]:
 				continue
 			for alias in item["aliases"]:
@@ -102,7 +114,7 @@ class StashInterface(GQLWrapper):
 				if ":" in alias:
 					parsed_alias = alias.split(":")[-1].strip()
 				if re.match(rf'{search}$', parsed_alias, re.IGNORECASE):
-					log.info(f'matched "{search}" to "{item["name"]}" ({item["id"]}) using alias')
+					self.log.info(f'matched performer "{search}" to "{item["name"]}" ({item["id"]}) using alias')
 					item_matches[item["id"]] = item
 		return list(item_matches.values())
 
@@ -111,20 +123,20 @@ class StashInterface(GQLWrapper):
 
 	def stash_version(self):
 		result = self._callGraphQL("query StashVersion{ version { build_time hash version } }")
-		return result['version']		
+		return StashVersion(result["version"])
 
 	def get_sql_interface(self):
 		if "localhost" in self.url or "127.0.0.1" in self.url:
 			sql_file = self.call_gql("query dbPath{configuration{general{databasePath}}}")
 			return SQLiteWrapper(sql_file["configuration"]["general"]["databasePath"])
 		else:
-			raise Exception("not local stash instance cannot create sql interface")
+			raise Exception(f"cannot create sql interface on a non local stash instance ({self.url})")
 
 	def graphql_configuration(self):
 		query = """
 			query Configuration {
 				configuration {
-					...ConfigData
+					...ConfigResult
 				}
 			}
 		"""
@@ -132,27 +144,48 @@ class StashInterface(GQLWrapper):
 		result = self._callGraphQL(query)
 		return result['configuration']
 
-	def metadata_scan(self, paths:list=[]):
+	def metadata_scan(self, paths:list=[], flags={}):
 		query = """
 		mutation metadataScan($input:ScanMetadataInput!) {
 			metadataScan(input: $input)
 		}
-		"""
-		variables = {
-			'input': {
-				'paths' : paths,
+		"""	
+		scan_metadata_input = {"paths": paths}
+		if flags:
+			scan_metadata_input.update(flags)
+		else:
+			scan_metadata_input.update({
 				'useFileMetadata': False,
 				'stripFileExtension': False,
 				'scanGeneratePreviews': False,
 				'scanGenerateImagePreviews': False,
 				'scanGenerateSprites': False,
 				'scanGeneratePhashes': True
-			}
-		}
-		result = self._callGraphQL(query, variables)
+			})
+		result = self._callGraphQL(query, {"input": scan_metadata_input})
 		return result
 
 	# Tag CRUD
+	def create_tag(self, tag_in:dict) -> dict:
+		"""creates tag in stash
+
+		Args:
+			 tag_in (dict): TagCreateInput to create a tag.
+
+		Returns:
+			 dict: stash Tag dict
+		"""
+
+		query = """
+			mutation tagCreate($input:TagCreateInput!) {
+				tagCreate(input: $input){
+					...Tag
+				}
+			}
+		"""
+		variables = {'input': tag_in}
+		result = self._callGraphQL(query, variables)
+		return result["tagCreate"]
 	def find_tag(self, tag_in, create=False) -> dict:
 		"""looks for tag from stash matching aliases
 
@@ -167,7 +200,7 @@ class StashInterface(GQLWrapper):
 		# assume input is an ID if int
 		if isinstance(tag_in, int):
 			return self.__genric_find(
-				"query FindTag($id: ID!) { findTag(id: $id) { ...stashTag } }",
+				"query FindTag($id: ID!) { findTag(id: $id) { ...Tag } }",
 				tag_in
 			)
 
@@ -181,7 +214,7 @@ class StashInterface(GQLWrapper):
 			name = tag_in
 
 		if not name:
-			log.warning(f'find_tag expects int, str, or dict not {type(tag_in)} "{tag_in}"')
+			self.log.warning(f'find_tag expects int, str, or dict not {type(tag_in)} "{tag_in}"')
 			return
 
 		for tag in self.find_tags(q=name):
@@ -191,27 +224,6 @@ class StashInterface(GQLWrapper):
 				return tag
 		if create:
 			return self.create_tag({"name":name})
-	
-	def create_tag(self, tag_in:dict) -> dict:
-		"""creates tag in stash
-
-		Args:
-			 tag_in (dict): TagCreateInput to create a tag.
-
-		Returns:
-			 dict: stash Tag dict
-		"""
-
-		query = """
-			mutation tagCreate($input:TagCreateInput!) {
-				tagCreate(input: $input){
-					...stashTag
-				}
-			}
-		"""
-		variables = {'input': tag_in}
-		result = self._callGraphQL(query, variables)
-		return result["tagCreate"]
 	def update_tag(self, tag_update):
 		query = """
 		mutation TagUpdate($input: TagUpdateInput!) {
@@ -241,7 +253,7 @@ class StashInterface(GQLWrapper):
 
 		self._callGraphQL(query, variables)
 
-	# Tags CRUD
+	# BULK Tags
 	def find_tags(self, f:dict={}, filter:dict={"per_page": -1}, q:str="", fragment:str=None, get_count:bool=False) -> list[dict]:
 		"""gets tags matching filter/query
 
@@ -249,7 +261,7 @@ class StashInterface(GQLWrapper):
 			 f (TagFilterType, optional): See playground for details. Defaults to {}.
 			 filter (FindFilterType, optional): See playground for details. Defaults to {"per_page": -1}.
 			 q (str, optional): query string, same search bar in stash. Defaults to "".
-			 fragment (str, optional): override for gqlFragment. Defaults to "...stashTag". example override 'fargment="id name"'
+			 fragment (str, optional): override for gqlFragment. Defaults to "...Tag". example override 'fargment="id name"'
 			 get_count (bool, optional): returns tuple (count, [tags]) where count is the number of results from the query, useful when pageing. Defaults to False.
 
 		Returns:
@@ -261,13 +273,13 @@ class StashInterface(GQLWrapper):
 				findTags(filter: $filter, tag_filter: $tag_filter) {
 					count
 					tags {
-						...stashTag
+						...Tag
 					}
 				}
 			}
 		"""
 		if fragment:
-			query = re.sub(r'\.\.\.stashTag', fragment, query)
+			query = re.sub(r'\.\.\.Tag', fragment, query)
 
 		filter["q"] = q
 		variables = {
@@ -282,6 +294,27 @@ class StashInterface(GQLWrapper):
 			return result["findTags"]["tags"]
 
 	# Performer CRUD
+	def create_performer(self, performer_in:dict) -> dict:
+		"""creates performer in stash
+
+		Args:
+			 performer_in (PerformerCreateInput): performer to create
+
+		Returns:
+			 dict: stash performer object
+		"""		
+		query = """
+			mutation($input: PerformerCreateInput!) {
+				performerCreate(input: $input) {
+					...Performer
+				}
+			}
+		"""
+
+		variables = {'input': performer_in}
+
+		result = self._callGraphQL(query, variables)
+		return result['performerCreate']
 	def find_performer(self, performer_in, create=False) -> dict:
 		"""looks for performer from stash matching aliases
 
@@ -296,7 +329,7 @@ class StashInterface(GQLWrapper):
 		# assume input is an ID if int
 		if isinstance(performer_in, int):
 			return self.__genric_find(
-				"query FindPerformer($id: ID!) { findPerformer(id: $id) { ...stashPerformer } }",
+				"query FindPerformer($id: ID!) { findPerformer(id: $id) { ...Performer } }",
 				performer_in,
 			)
 
@@ -310,7 +343,7 @@ class StashInterface(GQLWrapper):
 			name = performer_in
 
 		if not name:
-			log.warning(f'find_performer() expects int, str, or dict not {type(performer_in)} "{performer_in}"')
+			self.log.warning(f'find_performer() expects int, str, or dict not {type(performer_in)} "{performer_in}"')
 			return
 
 		name = name.strip()
@@ -326,7 +359,7 @@ class StashInterface(GQLWrapper):
 			elif len(p["aliases"]) > 0:
 				p["aliases"] = [p["aliases"]]
 			else:
-				log.warning(f'Could not determine delim for aliases "{p["aliases"]}"')
+				self.log.warning(f'Could not determine delim for aliases "{p["aliases"]}"')
 
 		performer_matches = self.__match_performer_alias(name, performers)
 
@@ -337,29 +370,8 @@ class StashInterface(GQLWrapper):
 			return performer_matches[0] 
 
 		if create:
-			log.info(f'Create missing performer: "{name}"')
+			self.log.info(f'Create missing performer: "{name}"')
 			return self.create_performer(performer_in)
-	def create_performer(self, performer_in:dict) -> dict:
-		"""creates performer in stash
-
-		Args:
-			 performer_in (PerformerCreateInput): performer to create
-
-		Returns:
-			 dict: stash performer object
-		"""		
-		query = """
-			mutation($input: PerformerCreateInput!) {
-				performerCreate(input: $input) {
-					...stashPerformer
-				}
-			}
-		"""
-
-		variables = {'input': performer_in}
-
-		result = self._callGraphQL(query, variables)
-		return result['performerCreate']
 	def update_performer(self, performer_in:dict) -> dict:
 		"""updates existing performer
 
@@ -373,7 +385,7 @@ class StashInterface(GQLWrapper):
 		query = """
 			mutation performerUpdate($input:PerformerUpdateInput!) {
 				performerUpdate(input: $input) {
-					...stashPerformer
+					...Performer
 				}
 			}
 		"""
@@ -381,7 +393,7 @@ class StashInterface(GQLWrapper):
 
 		result = self._callGraphQL(query, variables)
 		return result['performerUpdate']
-	# TODO delete_performer()
+	# TODO destroy_performer()
 
 	# Performers CRUD
 	def find_performers(self, f:dict={}, filter:dict={"per_page": -1}, q="", fragment:dict=None, get_count:bool=False) -> list[dict]:
@@ -391,7 +403,7 @@ class StashInterface(GQLWrapper):
 			 f (PerformerFilterType, optional): See playground for details. Defaults to {}.
 			 filter (FindFilterType, optional): See playground for details. Defaults to {"per_page": -1}.
 			 q (str, optional): query string, same search bar in stash. Defaults to "".
-			 fragment (dict, optional):  override for gqlFragment. Defaults to "...stashPerformer". example override 'fargment="id name"'
+			 fragment (dict, optional):  override for gqlFragment. Defaults to "...Performer". example override 'fargment="id name"'
 			 get_count (bool, optional): returns tuple (count, [performers]) where count is the number of results from the query, useful when pageing. Defaults to False.
 
 		Returns:
@@ -403,13 +415,13 @@ class StashInterface(GQLWrapper):
 				findPerformers(filter: $filter, performer_filter: $performer_filter) {
 					count
 					performers {
-						...stashPerformer
+						...Performer
 					}
 				}
 			}
 		"""
 		if fragment:
-			query = re.sub(r'\.\.\.stashPerformer', fragment, query)
+			query = re.sub(r'\.\.\.Performer', fragment, query)
 		
 		filter["q"] = q
 		variables = {
@@ -422,8 +434,42 @@ class StashInterface(GQLWrapper):
 			return result['findPerformers']['count'], result['findPerformers']['performers']
 		else:
 			return result['findPerformers']['performers']
+	def update_performers(self, bulk_performer_update_input:dict):
+		query = """
+			mutation BulkPerformerUpdate($input:BulkPerformerUpdateInput!) {
+				bulkPerformerUpdate(input: $input) {
+					id
+				}
+			}
+		"""
+		variables = {'input': bulk_performer_update_input}
+
+		result = self._callGraphQL(query, variables)
+		return result["bulkPerformerUpdate"]
 
 	# Studio CRUD
+	def create_studio(self, studio_create_input:dict) -> dict:
+		"""create studio in stash
+
+		Args:
+			 studio (StudioCreateInput): See playground for details
+
+		Returns:
+			 dict: stash studio object
+		"""		
+		query = """
+			mutation StudioCreate($input: StudioCreateInput!) {
+				studioCreate(input: $input) {
+					...Studio
+				}
+			}
+		"""
+		variables = {
+			'input': studio_create_input
+		}
+
+		result = self._callGraphQL(query, variables)
+		return result['studioCreate']
 	def find_studio(self, studio, create=False, domain_pattern=r'[^.]*\.[^.]{2,3}(?:\.[^.]{2,3})?$') -> dict:
 		"""looks for studio from stash matching aliases and URLs if name is like a url
 
@@ -439,7 +485,7 @@ class StashInterface(GQLWrapper):
 		# assume input is an ID if int
 		if isinstance(studio, int):
 			return self.__genric_find(
-				"query FindStudio($id: ID!) { findStudio(id: $id) { ...stashStudio } }",
+				"query FindStudio($id: ID!) { findStudio(id: $id) { ...Studio } }",
 				studio,
 			)
 
@@ -455,7 +501,7 @@ class StashInterface(GQLWrapper):
 			name = studio
 
 		if not name:
-			log.warning(f'find_studio() expects int, str, or dict not {type(studio)} "{studio}"')
+			self.log.warning(f'find_studio() expects int, str, or dict not {type(studio)} "{studio}"')
 			return
 		name = name.strip()
 
@@ -468,7 +514,7 @@ class StashInterface(GQLWrapper):
 			})
 			for s in url_search:
 				if re.search(rf'{name}',s["url"]):
-					log.info(f'matched "{name}" to {s["url"]} using URL')
+					self.log.info(f'matched "{name}" to {s["url"]} using URL')
 					studio_matches.append(s)
 
 		name_results = self.find_studios(q=name)
@@ -480,30 +526,8 @@ class StashInterface(GQLWrapper):
 			return studio_matches[0] 
 
 		if create:
-			log.info(f'Create missing studio: "{name}"')
+			self.log.info(f'Create missing studio: "{name}"')
 			return self.create_studio(studio)
-	def create_studio(self, studio:dict) -> dict:
-		"""create studio in stash
-
-		Args:
-			 studio (StudioCreateInput): See playground for details
-
-		Returns:
-			 dict: stash studio object
-		"""		
-		query = """
-			mutation StudioCreate($input: StudioCreateInput!) {
-				studioCreate(input: $input) {
-					...stashStudio
-				}
-			}
-		"""
-		variables = {
-			'name': studio
-		}
-
-		result = self._callGraphQL(query, variables)
-		return result['studioCreate']
 	def update_studio(self, studio:dict):
 		"""update existing stash studio
 
@@ -517,7 +541,7 @@ class StashInterface(GQLWrapper):
 		query = """
 			mutation StudioUpdate($input:StudioUpdateInput!) {
 				studioUpdate(input: $input) {
-					...stashStudio
+					...Studio
 				}
 			}
 		"""
@@ -525,8 +549,9 @@ class StashInterface(GQLWrapper):
 
 		result = self._callGraphQL(query, variables)
 		return result["studioUpdate"]
-	# TODO delete_studio()
+	# TODO destroy_studio()
 
+	# BULK Studios
 	def find_studios(self, f:dict={}, filter:dict={"per_page": -1}, q:str="", fragment:str=None, get_count:bool=False):
 		"""get studios matching filter/query
 
@@ -534,7 +559,7 @@ class StashInterface(GQLWrapper):
 			 f (StudioFilterType, optional): See playground for details. Defaults to {}.
 			 filter (FindFilterType, optional): See playground for details. Defaults to {"per_page": -1}.
 			 q (str, optional): query string, same search bar in stash. Defaults to "".
-			 fragment (_type_, optional): override for gqlFragment. Defaults to "...stashStudio". example override 'fargment="id name"'
+			 fragment (_type_, optional): override for gqlFragment. Defaults to "...Studio". example override 'fargment="id name"'
 			 get_count (bool, optional): returns tuple (count, [studios]) where count is the number of results from the query, useful when pageing. Defaults to False.
 
 		Returns:
@@ -546,13 +571,13 @@ class StashInterface(GQLWrapper):
 			findStudios(filter: $filter, studio_filter: $studio_filter) {
 			count
 			studios {
-				...stashStudio
+				...Studio
 			}
 			}
 		}
 		"""
 		if fragment:
-			query = re.sub(r'\.\.\.stashStudio', fragment, query)
+			query = re.sub(r'\.\.\.Studio', fragment, query)
 
 		filter["q"] = q
 		variables = {
@@ -567,11 +592,27 @@ class StashInterface(GQLWrapper):
 			return result['findStudios']['studios']
 
 	# Movie CRUD
+	def create_movie(self, movie_in):
+		if isinstance(movie_in, str):
+			movie_in = {"name": movie_in}
+		if not isinstance(movie_in, dict):
+			self.log.warning(f"could not create movie from {movie_in}")
+			return
+		query = """
+			mutation($input: MovieCreateInput!) {
+				movieCreate(input: $input) {
+					id
+				}
+			}
+		"""
+		variables = {'input': movie_in}
+		result = self._callGraphQL(query, variables)
+		return result['movieCreate']
 	def find_movie(self, movie_in, create=False):
 		# assume input is an ID if int
 		if isinstance(movie_in, int):
 			return self.__genric_find(
-				"query FindMovie($id: ID!) { findMovie(id: $id) { ...stashMovie } }",
+				"query FindMovie($id: ID!) { findMovie(id: $id) { ...Movie } }",
 				movie_in
 			)
 
@@ -594,33 +635,17 @@ class StashInterface(GQLWrapper):
 			if len(movie_matches) == 1:
 				return movie_matches[0]
 			else:
-				log.warning(f'Too many matches for movie "{name}"')
+				self.log.warning(f'Too many matches for movie "{name}"')
 				return None
 
 		if create:
-			log.info(f'Creating missing Movie "{name}"')
+			self.log.info(f'Creating missing Movie "{name}"')
 			return self.create_movie(movie_in)
-	def create_movie(self, movie_in):
-		if isinstance(movie_in, str):
-			movie_in = {"name": movie_in}
-		if not isinstance(movie_in, dict):
-			log.warning(f"could not create movie from {movie_in}")
-			return
-		query = """
-			mutation($input: MovieCreateInput!) {
-				movieCreate(input: $input) {
-					id
-				}
-			}
-		"""
-		variables = {'input': movie_in}
-		result = self._callGraphQL(query, variables)
-		return result['movieCreate']
 	def update_movie(self, movie_in):
 		query = """
 			mutation MovieUpdate($input:MovieUpdateInput!) {
 				movieUpdate(input: $input) {
-					...stashMovie
+					...Movie
 				}
 			}
 		"""
@@ -628,22 +653,22 @@ class StashInterface(GQLWrapper):
 
 		result = self._callGraphQL(query, variables)
 		return result['movieUpdate']
-	# TODO delete_movie()
+	# TODO destroy_movie()
 
-	# Movies CRUD
+	# BULK Movies
 	def find_movies(self, f:dict={}, filter:dict={"per_page": -1}, q="", fragment=None, get_count=False):
 		query = """
 			query FindMovies($filter: FindFilterType, $movie_filter: MovieFilterType) {
 				findMovies(filter: $filter, movie_filter: $movie_filter) {
 					count
 					movies {
-						...stashMovie
+						...Movie
 					}
 				}
 			}
 		"""
 		if fragment:
-			query = re.sub(r'\.\.\.stashMovie', fragment, query)
+			query = re.sub(r'\.\.\.Movie', fragment, query)
 
 		filter["q"] = q
 		variables = {
@@ -664,9 +689,9 @@ class StashInterface(GQLWrapper):
 	def find_gallery(self, gallery_in, fragment=None):
 		if isinstance(gallery_in, int):
 			return self.__genric_find(
-				"query FindGallery($id: ID!) { findGallery(id: $id) { ...stashGallery } }",
+				"query FindGallery($id: ID!) { findGallery(id: $id) { ...Gallery } }",
 				gallery_in,
-				(r'\.\.\.stashGallery', fragment)
+				(r'\.\.\.Gallery', fragment)
 			)
 
 		if isinstance(gallery_in, dict):
@@ -677,7 +702,7 @@ class StashInterface(GQLWrapper):
 			try:
 				return self.find_tag(int(gallery_in))
 			except:
-				log.warning(f"could not parse {gallery_in} to Gallery ID (int)")
+				self.log.warning(f"could not parse {gallery_in} to Gallery ID (int)")
 	def update_gallery(self, gallery_data):
 		query = """
 			mutation GalleryUpdate($input:GalleryUpdateInput!) {
@@ -690,18 +715,6 @@ class StashInterface(GQLWrapper):
 
 		result = self._callGraphQL(query, variables)
 		return result["galleryUpdate"]["id"]
-	def update_galleries(self, galleries_input):
-		query = """
-			mutation BulkGalleryUpdate($input:BulkGalleryUpdateInput!) {
-				bulkGalleryUpdate(input: $input) {
-					id
-				}
-			}
-		"""
-		variables = {'input': galleries_input}
-
-		result = self._callGraphQL(query, variables)
-		return result["bulkGalleryUpdate"]
 	def destroy_gallery(self, gallery_ids, delete_file=False, delete_generated=True):
 		if isinstance(gallery_ids, int):
 			gallery_ids = [gallery_ids]
@@ -730,13 +743,13 @@ class StashInterface(GQLWrapper):
 				findGalleries(gallery_filter: $gallery_filter, filter: $filter) {
 					count
 					galleries {
-						...stashGallery
+						...Gallery
 					}
 				}
 			}
 		"""
 		if fragment:
-			query = re.sub(r'\.\.\.stashGallery', fragment, query)
+			query = re.sub(r'\.\.\.Gallery', fragment, query)
 
 		filter["q"] = q
 		variables = {
@@ -749,6 +762,18 @@ class StashInterface(GQLWrapper):
 			return result['findGalleries']['count'], result['findGalleries']['galleries']
 		else:
 			return result['findGalleries']['galleries']
+	def update_galleries(self, galleries_input):
+		query = """
+			mutation BulkGalleryUpdate($input:BulkGalleryUpdateInput!) {
+				bulkGalleryUpdate(input: $input) {
+					id
+				}
+			}
+		"""
+		variables = {'input': galleries_input}
+
+		result = self._callGraphQL(query, variables)
+		return result["bulkGalleryUpdate"]
 
 	# Image CRUD
 	def create_image(self, path:str=""):
@@ -757,9 +782,9 @@ class StashInterface(GQLWrapper):
 	def find_image(self, image_in, fragment=None):
 		if isinstance(image_in, int):
 			return self.__genric_find(
-				"query FindImage($id: ID!) { findImage(id: $id) { ...stashImage } }",
+				"query FindImage($id: ID!) { findImage(id: $id) { ...Image } }",
 				image_in,
-				(r'\.\.\.stashImage', fragment),
+				(r'\.\.\.Image', fragment),
 			)
 
 		if isinstance(image_in, dict):
@@ -772,34 +797,9 @@ class StashInterface(GQLWrapper):
 			try:
 				return self.find_tag(int(image_in))
 			except:
-				log.warning(f"could not parse {image_in} to Image ID (int)")
+				self.log.warning(f"could not parse {image_in} to Image ID (int)")
 
-		log.warning(f'find_image expects int, str, or dict not {type(image_in)} "{image_in}"')
-	def find_images(self, f:dict={}, filter:dict={"per_page": -1}, q="", fragment=None, get_count=False):
-		query = """
-		query FindImages($filter: FindFilterType, $image_filter: ImageFilterType, $image_ids: [Int!]) {
-  			findImages(filter: $filter, image_filter: $image_filter, image_ids: $image_ids) {
-    			count
-    			images {
-      			...stashImage
-    			}
-  			}
-		}
-		"""
-		if fragment:
-			query = re.sub(r'\.\.\.stashImage', fragment, query)
-
-		filter["q"] = q
-		variables = {
-			"filter": filter,
-			"image_filter": f
-		}
-
-		result = self._callGraphQL(query, variables)
-		if get_count:
-			return result['findImages']['count'], result['findImages']['images']
-		else:
-			return result['findImages']['images']
+		self.log.warning(f'find_image expects int, str, or dict not {type(image_in)} "{image_in}"')
 	def update_image(self, update_input):
 		query = """
 			mutation ImageUpdate($input:ImageUpdateInput!) {
@@ -812,18 +812,6 @@ class StashInterface(GQLWrapper):
 
 		result = self._callGraphQL(query, variables)
 		return result["imageUpdate"]
-	def update_images(self, updates_input):
-		query = """
-			mutation BulkImageUpdate($input:BulkImageUpdateInput!) {
-				bulkImageUpdate(input: $input) {
-					id
-				}
-			}
-		"""
-		variables = {'input': updates_input}
-
-		result = self._callGraphQL(query, variables)
-		return result["bulkImageUpdate"]
 	def destroy_image(self, image_id, delete_file=False):
 		query = """
 		mutation ImageDestroy($input:ImageDestroyInput!) {
@@ -840,6 +828,45 @@ class StashInterface(GQLWrapper):
 			
 		result = self._callGraphQL(query, variables)
 		return result['imageDestroy']
+	
+	# BULK Images
+	def find_images(self, f:dict={}, filter:dict={"per_page": -1}, q="", fragment=None, get_count=False):
+		query = """
+		query FindImages($filter: FindFilterType, $image_filter: ImageFilterType, $image_ids: [Int!]) {
+  			findImages(filter: $filter, image_filter: $image_filter, image_ids: $image_ids) {
+	 			count
+	 			images {
+					...Image
+	 			}
+  			}
+		}
+		"""
+		if fragment:
+			query = re.sub(r'\.\.\.Image', fragment, query)
+
+		filter["q"] = q
+		variables = {
+			"filter": filter,
+			"image_filter": f
+		}
+
+		result = self._callGraphQL(query, variables)
+		if get_count:
+			return result['findImages']['count'], result['findImages']['images']
+		else:
+			return result['findImages']['images']		
+	def update_images(self, updates_input):
+		query = """
+			mutation BulkImageUpdate($input:BulkImageUpdateInput!) {
+				bulkImageUpdate(input: $input) {
+					id
+				}
+			}
+		"""
+		variables = {'input': updates_input}
+
+		result = self._callGraphQL(query, variables)
+		return result["bulkImageUpdate"]
 	def destroy_images(self, image_ids:list, delete_file=False):
 		query = """
 		mutation ImagesDestroy($input:ImagesDestroyInput!) {
@@ -865,12 +892,12 @@ class StashInterface(GQLWrapper):
 		query = """
 		query FindScene($scene_id: ID) {
 			findScene(id: $scene_id) {
-				...stashScene
+				...Scene
 			}
 		}
 		"""
 		if fragment:
-			query = re.sub(r'\.\.\.stashScene', fragment, query)
+			query = re.sub(r'\.\.\.Scene', fragment, query)
 
 		variables = {"scene_id": id}
 
@@ -914,13 +941,13 @@ class StashInterface(GQLWrapper):
 			findScenes(filter: $filter, scene_filter: $scene_filter, scene_ids: $scene_ids) {
 				count
 				scenes {
-					...stashScene
+					...Scene
 				}
 			}
 		}
 		"""
 		if fragment:
-			query = re.sub(r'\.\.\.stashScene', fragment, query)
+			query = re.sub(r'\.\.\.Scene', fragment, query)
 
 		filter["q"] = q
 		variables = {
@@ -962,18 +989,19 @@ class StashInterface(GQLWrapper):
 		result = self._callGraphQL(query, variables)
 		return result['scenesDestroy']
 
+	# Markers CRUD
 	def find_scene_markers(self, scene_id, fragment=None) -> list:
 		query = """
 			query FindSceneMarkers($scene_id: ID) {
 				findScene(id: $scene_id) {
 					scene_markers {
-						...stashSceneMarker
+						...SceneMarker
 					}
 				}
 			}
 		"""
 		if fragment:
-			query = re.sub(r'\.\.\.stashSceneMarker', fragment, query)
+			query = re.sub(r'\.\.\.SceneMarker', fragment, query)
 
 		variables = { "scene_id": scene_id }
 		return self._callGraphQL(query, variables)["findScene"]["scene_markers"]
@@ -981,12 +1009,12 @@ class StashInterface(GQLWrapper):
 		query = """
 			mutation SceneMarkerCreate($marker_input: SceneMarkerCreateInput!) {
 				sceneMarkerCreate(input: $marker_input) {
-					...stashSceneMarker
+					...SceneMarker
 				}
 			}
 		"""
 		if fragment:
-			query = re.sub(r'\.\.\.stashSceneMarker', fragment, query)
+			query = re.sub(r'\.\.\.SceneMarker', fragment, query)
 			
 		variables = { "marker_input": marker_create_input }
 		return self._callGraphQL(query, variables)["sceneMarkerCreate"]
@@ -997,6 +1025,8 @@ class StashInterface(GQLWrapper):
 			}
 		"""
 		self._callGraphQL(query, {"marker_id": marker_id})
+	
+	# BULK Markers
 	def destroy_scene_markers(self, scene_id:int):
 		scene_markers = self.find_scene_markers(scene_id, fragment="id")
 		for marker in scene_markers:
@@ -1024,6 +1054,7 @@ class StashInterface(GQLWrapper):
 			created_markers.append(marker_id)
 		return created_markers
 
+	# Scene Utils
 	def destroy_scene_stash_id(self, stash_id):
 		scenes = self.find_scenes(f={
 			"stash_id": {
@@ -1035,7 +1066,6 @@ class StashInterface(GQLWrapper):
 		for scene in scenes:
 			scene["stash_ids"] = [sid for sid in scene["stash_ids"] if sid["stash_id"] != stash_id ]
 			self.update_scene(scene)
-
 	def merge_scenes(self, target_scene_id:int, source_scene_ids:list, exclusions={}):
 
 		min_scene_fragment="""
@@ -1052,7 +1082,7 @@ class StashInterface(GQLWrapper):
 		"""
 
 		merged_markers = self.merge_scene_markers(target_scene_id, source_scene_ids)
-		log.info(f"Merged {len(merged_markers)} markers from {source_scene_ids} to {target_scene_id}")
+		self.log.info(f"Merged {len(merged_markers)} markers from {source_scene_ids} to {target_scene_id}")
 
 		target_meta = self.find_scene(target_scene_id, fragment=min_scene_fragment)
 
@@ -1093,6 +1123,20 @@ class StashInterface(GQLWrapper):
 			updated_scene_ids = self.update_scenes(scene_update)
 
 		return updated_scene_ids
+	def find_duplicate_scenes(self, distance: PhashDistance=PhashDistance.EXACT, fragment=None):
+		query = """
+			query FindDuplicateScenes($distance: Int) {
+				findDuplicateScenes(distance: $distance) {
+					...SceneSlim
+				}
+			}
+		"""
+		if fragment:
+			query = re.sub(r'\.\.\.SceneSlim', fragment, query)
+
+		variables = { "distance": distance }
+		result = self._callGraphQL(query, variables)
+		return result['findDuplicateScenes']
 
 	# Scraper Operations
 	def reload_scrapers(self):
@@ -1201,13 +1245,13 @@ class StashInterface(GQLWrapper):
 			if not isinstance(scene_id, int):
 				raise Exception("scene_id must be an int")
 		except:
-			log.warning('Unexpected Object passed to scrape_single_scene')
-			log.warning(f'Type: {type(scene)}')
-			log.warning(f'{scene}')
+			self.log.warning('Unexpected Object passed to scrape_single_scene')
+			self.log.warning(f'Type: {type(scene)}')
+			self.log.warning(f'{scene}')
 
 		query = """query ScrapeSingleScene($source: ScraperSourceInput!, $input: ScrapeSingleSceneInput!) {
 			scrapeSingleScene(source: $source, input: $input) {
-			  ...scrapedScene
+			  ...ScrapedScene
 			}
 		  }
 		"""
@@ -1233,7 +1277,7 @@ class StashInterface(GQLWrapper):
 	def scrape_gallery(self, scraper_id:int, gallery):
 		query = """query ScrapeGallery($scraper_id: ID!, $gallery: GalleryUpdateInput!) {
 			scrapeGallery(scraper_id: $scraper_id, gallery: $gallery) {
-			  ...scrapedGallery
+			  ...ScrapedGallery
 			}
 		  }
 		"""
@@ -1258,7 +1302,7 @@ class StashInterface(GQLWrapper):
 	def scrape_performer(self, scraper_id:int, performer):
 		query = """query ScrapePerformer($scraper_id: ID!, $performer: ScrapedPerformerInput!) {
 			scrapePerformer(scraper_id: $scraper_id, performer: $performer) {
-			  ...scrapedPerformer
+			  ...ScrapedPerformer
 			}
 		  }
 		"""
@@ -1297,7 +1341,7 @@ class StashInterface(GQLWrapper):
 		query = """
 			query($url: String!) {
 				scrapeSceneURL(url: $url) {
-					...scrapedScene
+					...ScrapedScene
 				}
 			}
 		"""
@@ -1310,7 +1354,7 @@ class StashInterface(GQLWrapper):
 		query = """
 			query($url: String!) {
 				scrapeMovieURL(url: $url) {
-					...scrapedMovie
+					...ScrapedMovie
 				}
 			}
 		"""
@@ -1323,7 +1367,7 @@ class StashInterface(GQLWrapper):
 		query = """
 			query($url: String!) {
 				scrapeGalleryURL(url: $url) {
-					...scrapedGallery 
+					...ScrapedGallery 
 				}
 			}
 		"""
@@ -1336,7 +1380,7 @@ class StashInterface(GQLWrapper):
 		query = """
 			query($url: String!) {
 				scrapePerformerURL(url: $url) {
-					...scrapedPerformer
+					...ScrapedPerformer
 				}
 			}
 		"""
@@ -1409,7 +1453,7 @@ class StashInterface(GQLWrapper):
 			if sbox_endpoint in sbox_cfg["endpoint"]:
 				sbox_cfg["index"] = sbox_idx
 				return sbox_cfg
-		log.error(f'could not find stash-box conection to "{sbox_endpoint}"')
+		self.log.error(f'could not find stash-box conection to "{sbox_endpoint}"')
 		return {}
 	def get_stashbox_connections(self):
 		query = """
@@ -1430,7 +1474,7 @@ class StashInterface(GQLWrapper):
 		query = """
 			query QueryStashBoxScene($input: StashBoxSceneQueryInput!) {
 				queryStashBoxScene(input: $input) {
-					...scrapedScene
+					...ScrapedScene
 				}
 			}
 		"""
@@ -1492,19 +1536,3 @@ class StashInterface(GQLWrapper):
 		} }
 		result = self._callGraphQL(query, variables)
 		return result['submitStashBoxSceneDraft']
-
-	def find_duplicate_scenes(self, distance: PhashDistance=PhashDistance.EXACT, fragment=None):
-		query = """
-			query FindDuplicateScenes($distance: Int) {
-				  findDuplicateScenes(distance: $distance) {
-					...stashSceneSlim
-					__typename
-				  }
-			}
-		"""
-		if fragment:
-			query = re.sub(r'\.\.\.stashSceneSlim', fragment, query)
-
-		variables = { "distance": distance }
-		result = self._callGraphQL(query, variables)
-		return result['findDuplicateScenes']
